netapp_ontap.models.snapmirror_policy_rule API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.snapmirror_policy_rule`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SnapmirrorPolicyRuleSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SnapmirrorPolicyRule object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `count GET POST PATCH`

    Number of Snapshot copies to be kept for retention.

    Example: 7

  `creation_schedule GET POST PATCH`

    The creation_schedule field of the snapmirror_policy_rule.

  `label GET POST PATCH`

    Snapshot copy label

    Example: hourly

  `prefix GET POST PATCH`

    Specifies the prefix for the Snapshot copy name to be created as per the schedule. If no value is specified, then the label is used as the prefix.